"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const Timer_1 = require("../../lib/Timer");
const _utils_1 = require("../_utils");
const timeout = { id: 'ackTo', length: 40 };
ava_1.default.beforeEach(t => t.context.timer = new Timer_1.default());
ava_1.default.afterEach(t => t.context.timer.clear());
ava_1.default('[unit] #restartTimeouts throws on missing entries', t => {
    t.throws(() => t.context.timer.restartTimeouts('an-id'));
});
ava_1.default('[unit] #restartTimeouts throws on missing timeouts', t => {
    t.context.timer.addTimeouts('an-id', timeout);
    t.throws(() => t.context.timer.restartTimeouts('an-id', 'otherTo'));
});
ava_1.default('[unit] #restartTimeouts restarts the given timeout', async (t) => {
    t.plan(2);
    const start = Date.now();
    const promise = t.context.timer.addTimeouts('an-id', timeout, { id: 'slowTo', length: 50 });
    await _utils_1.delay(20);
    t.context.timer.restartTimeouts('an-id', timeout.id, 'slowTo');
    await promise.catch(err => {
        t.regex(err.message, /ackTo.*40/);
        t.true(Date.now() >= start + 60);
    });
});
ava_1.default('[unit] #restartTimeouts does not affect other timeouts', async (t) => {
    t.plan(2);
    const start = Date.now();
    const promise = t.context.timer.addTimeouts('an-id', timeout, { id: 'slowTo', length: 50 });
    await _utils_1.delay(20);
    t.context.timer.restartTimeouts('an-id', timeout.id);
    await promise.catch(err => {
        t.regex(err.message, /slowTo.*50/);
        t.true(Date.now() >= start + 50);
    });
});
